@@ -19,4 +19,4 @@ utils::globalVariables(c('r','variation2','variation3','syn_id','rs_id','checkSy
                          'dist2','i','population','feature_type',
                          'external_name','gene_id','id','d_prime',
                          'name','size','description','r2','Gene',
-                         'Pos_37','Cytoband','gSNP','Linked_SNP','number','Alleles'))
+                         'Pos_37','Cytoband','gSNP','Linked_SNP','number','Alleles','Deleteriousness'))
